==> haskell-quickcheck-assertions-0.3.0-377-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-8ksH1jL3tVstTyHc4yV6a
key:                  quickcheck-assertions-0.3.0-8ksH1jL3tVstTyHc4yV6a
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  940f254f21bc64470b0a7e13bcfbee62
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-8ksH1jL3tVstTyHc4yV6a
depends:
    QuickCheck-2.15.0.1-6OtfWMF4tzoHoYkQbgugv4 base-4.17.2.1
    ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
    pretty-show-1.10-Dwgsrh12Px3tJNgclFhNg

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-378-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-assertions
version:              0.3.0
visibility:           public
id:                   quickcheck-assertions-0.3.0-A4lkpMjmV0C9EDQ1AwDkxN
key:                  quickcheck-assertions-0.3.0-A4lkpMjmV0C9EDQ1AwDkxN
license:              LGPL-3.0-only
maintainer:           s9gf4ult@gmail.com
author:               Aleksey Uymanov
homepage:             https://github.com/s9gf4ult/quickcheck-assertions
synopsis:             HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit

category:             Testing
abi:                  f5ce197ebc213cb85cbe69776a9a44fa
exposed:              True
exposed-modules:      Test.QuickCheck.Assertions
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-assertions
hs-libraries:         HSquickcheck-assertions-0.3.0-A4lkpMjmV0C9EDQ1AwDkxN
depends:
    QuickCheck-2.15.0.1-HjS4TEwsqmECLyEigdP31V base-4.17.2.1
    ieee754-0.8.0-ASOHKK3CShAKvOX7rImTkX
    pretty-show-1.10-Dwgsrh12Px3tJNgclFhNg

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
